# pastemyst-py

api wrapper for [pastemyst-v2](https://paste.myst.rs) written in python.

<br>

## install

install using pip:
```
  pip install pastemyst
```

<br>

## requirements

Here's the libraries used to create the wrapper:
- time
- json
- asks
- trio
- multio
- datetime
- collections

<br>

## usage

you can find a simple usage example in `/test/basic.py`.

<br>

## contribution

feel free to make a pull request or open an issue. all help is welcome.

<br>

## license

this repo is licensed under mit license.

<br>

## maintainers

- [Munchii](https://github.com/Dmunch04) (me)
